// src/index.ts
var MessageQueue = class {
  constructor(options) {
    this._queue = [];
    this._flushing = false;
    this._ready = false;
    this._send = options.send;
    this._isReady = options.isReady;
    this._flushTimeout = options.flushTimeout || 16;
  }
  get ready() {
    return this._ready || (this._ready = this._isReady());
  }
  flush() {
    if (!this.ready) {
      return;
    }
    this._flush();
  }
  _flush() {
    if (this._flushing) {
      return;
    }
    this._flushing = true;
    while (this._queue.length > 0) {
      const e = this._queue.shift();
      this._send(e);
    }
    this._flushing = false;
  }
  push(data) {
    this._queue.push(data);
    this.flush();
  }
  clear() {
    this._queue = [];
    this._flushing = false;
  }
  dispose() {
    this.clear();
  }
  get length() {
    return this._queue.length;
  }
  scheduleFlush() {
    if (this.length === 0) {
      return;
    }
    if (this.ready) {
      this._flush();
      return;
    }
    if (this.scheduled) {
      clearTimeout(this.scheduled);
    }
    this.scheduled = setTimeout(() => {
      this.scheduleFlush();
    }, this._flushTimeout);
  }
};
export {
  MessageQueue
};
